// this function verifies disk space in kilobytes
function verifyDiskSpace(dirPath, spaceRequired)
{
  var spaceAvailable;

  // Get the available disk space on the given path
  spaceAvailable = fileGetDiskSpaceAvailable(dirPath);

  // Convert the available disk space into kilobytes
  spaceAvailable = parseInt(spaceAvailable / 1024);

  // do the verification
  if(spaceAvailable < spaceRequired)
  {
    logComment("Insufficient disk space: " + dirPath);
    logComment("  required : " + spaceRequired + " K");
    logComment("  available: " + spaceAvailable + " K");
    return(false);
  }

  return(true);
}

// OS type detection
// which platform?
function getPlatform()
{
  var platformStr;
  var platformNode;

  if('platform' in Install)
  {
    platformStr = new String(Install.platform);

    if (!platformStr.search(/^Macintosh/))
      platformNode = 'mac';
    else if (!platformStr.search(/^Win/))
      platformNode = 'win';
    else
      platformNode = 'unix';
  }
  else
  {
    var fOSMac  = getFolder("Mac System");
    var fOSWin  = getFolder("Win System");

    logComment("fOSMac: "  + fOSMac);
    logComment("fOSWin: "  + fOSWin);

    if(fOSMac != null)
      platformNode = 'mac';
    else if(fOSWin != null)
      platformNode = 'win';
    else
      platformNode = 'unix';
  }

  return platformNode;
}


var srDest = 724;
var err;
var fProgram;
var platformNode;

platformNode = getPlatform();
logComment("initInstall: platformNode=" + platformNode);
// end - OS type detection

// --- LOCALIZATION NOTE: translate only these ---
var prettyName = "Esperantlingva Pako";
var langcode = "eo";
var regioncode = "EO";
var chromeNode = langcode + "-" + regioncode;
// --- END LOCALIZABLE RESOURCES ---
var regName    = "locales/mozilla/" + chromeNode;
var chromeName = chromeNode + ".jar";
var regionFile = regioncode + ".jar";
var platformName = langcode + "-" + platformNode + ".jar";
var localeName = "locale/" + chromeNode + "/";
var regionName = "locale/" + regioncode + "/";

err = initInstall(prettyName, regName, "1.4"); 
logComment("initInstall: " + err);

fProgram = getFolder("Program");
logComment("fProgram: " + fProgram);

if (verifyDiskSpace(fProgram, srDest))
{
    var chromeType = LOCALE;
    // DELAYED_CHROME is still needed on many systems for bug 109044
    chromeType |= DELAYED_CHROME;
    err = addDirectory("","bin",fProgram,"");
    logComment("addDirectory() returned: " + err);

    if (err != SUCCESS)
    {
        logComment("addDirectory() to " + fProgram + "failed!");
 
        // couldn't install globally, try installing to the profile

// does not work with DELAYED_CHROME !!!
//        resetError();
//        chromeType |= PROFILE_CHROME;
//        fProgram = getFolder("Profile");
//        logComment("try installing to the user profile:" + fProgram);
//        err = addDirectory("","bin/chrome",fProgram,"chrome");
    }
 
    setPackageFolder(fProgram);
 
    // check return value
    if ((err == SUCCESS) || (err == REBOOT_NEEDED))
    {
        var tellReboot = 0;
        if (err == REBOOT_NEEDED) {
           tellReboot = 1;
           resetError();
        }
        // register chrome
        var cf = getFolder(fProgram, "chrome/"+chromeName);
        var pf = getFolder(fProgram, "chrome/"+platformName);
        var rf = getFolder(fProgram, "chrome/"+regionFile);

        registerChrome(chromeType, cf, localeName + "global/");
        registerChrome(chromeType, cf, localeName + "communicator/");
        registerChrome(chromeType, cf, localeName + "content-packs/");
        registerChrome(chromeType, cf, localeName + "cookie/");
        registerChrome(chromeType, cf, localeName + "editor/");
        registerChrome(chromeType, cf, localeName + "forms/");
        registerChrome(chromeType, cf, localeName + "help/");
        registerChrome(chromeType, cf, localeName + "messenger/");
        registerChrome(chromeType, cf, localeName + "messenger-mdn/");
        registerChrome(chromeType, cf, localeName + "messenger-smime/");
        registerChrome(chromeType, cf, localeName + "mozldap/");
        registerChrome(chromeType, cf, localeName + "navigator/");
        registerChrome(chromeType, cf, localeName + "necko/");
        registerChrome(chromeType, cf, localeName + "pipnss/");
        registerChrome(chromeType, cf, localeName + "pippki/");
        registerChrome(chromeType, cf, localeName + "wallet/");

        registerChrome(chromeType, pf, localeName + "global-platform/");
        registerChrome(chromeType, pf, localeName + "communicator-platform/");
        registerChrome(chromeType, pf, localeName + "navigator-platform/");
        if (platformNode == "win") {
          registerChrome(chromeType, pf, localeName + "messenger-mapi/");
        }

	// Regional content
        registerChrome(chromeType, rf, regionName + "global-region/");
        registerChrome(chromeType, rf, regionName + "communicator-region/");
        registerChrome(chromeType, rf, regionName + "editor-region/");
        registerChrome(chromeType, rf, regionName + "messenger-region/");
        registerChrome(chromeType, rf, regionName + "navigator-region/");

        err = performInstall(); 
        logComment("performInstall() returned: " + err);
        if (err == SUCCESS || err == REBOOT_NEEDED)
        {
           if (tellReboot == 1)
           {
               alert("Instalado finita.\n\nBonvolu kontroli la pagxon http://www.esperanto.org.uy/mozilo de tempo al tempo cxar novaj versioj de tiu cxi lingva pako aperos tie unue.\n\nSe vi trovas erarojn aux volas kunlabori en la traduko ne hezitu skribi al mozilo-esperanta@esperanto.org.uy.\n\nVi devos rekomenci la sistemon antaux ol vi povos elekti la esperantan lingvon el la menuo:\nRedakti->Preferoj->Aspekto->Lingvoj.");
           }
           else
           {
               alert("Mozila lingva pako 1.4.eo.1 sukcese instalita.\n\nVi trovos pliajn informojn kaj la plej aktualajn versiojn \u0109e http://www.esperanto.org.uy/mozilo\n\nSe vi volas sciigi min pri eraroj a\u016d \u015datus kunlabori en la traduko ne hezitu skribi al etrapani@esperanto.org.uy.\n\nVi devos rekomenci la programon anta\u016d ol elekti la esperantan lingvon el la menuo:\nRedakti->Preferoj->Aspekto->Lingvoj (tio aperos en via nuna lingvo)");
           }
        }
        else
        {
               alert("Instalado malsukcesis. La eraro estis " + err);
        }
    }
    else
    {
        cancelInstall(err);
        logComment("cancelInstall due to error: " + err);
        if (err == -202) {
           alert("Instalado nuligita, eraro " + err +". Sxajnas ke vi ne havas person por modifi la dosierujon 'chrome' de Mozilo. Instalu la lingvan pakon kiel root aux la sistema admnistranto.");
        }
        else {
           alert("Instalado malsukcesis.  La eraro estis " + err);
        }
    }
}
else
    cancelInstall(INSUFFICIENT_DISK_SPACE);
